Curves.Utils.Plotting (curves v0.2.3)

Copy Markdown View Source

These are helper functions for making it easier to plot curves with VegaLite.

Summary

Functions

Given a curve, build a list of points, in map format.

Functions

curve_to_scatterplot(curve, opts \\ [])

Given a curve, build a list of points, in map format.

Opts

  • :label, default: "Curve"
  • :count, default: 1000