These are helper functions for making it easier to plot curves with VegaLite.
Summary
Functions
Given a curve, build a list of points, in map format.
These are helper functions for making it easier to plot curves with VegaLite.
Given a curve, build a list of points, in map format.